VampireTokenType

Enum VampireTokenType 

pub enum VampireTokenType {
Show 91 variants Eof, Whitespace, LineComment, BlockComment, StringLiteral, IntegerLiteral, RealLiteral, Identifier, FofKw, CnfKw, TffKw, ThfKw, TpiKw, IncludeKw, AxiomKw, HypothesisKw, DefinitionKw, AssumptionKw, LemmaKw, TheoremKw, ConjectureKw, NegatedConjectureKw, PlainKw, TypeKw, FiDomainKw, FiFunctorsKw, FiPredicatesKw, UnknownKw, ForallKw, ExistsKw, AndKw, OrKw, NotKw, ImpliesKw, IffKw, XorKw, NorKw, NandKw, BoolKw, IndividualKw, IntKw, RealKw, RatKw, TTypeKw, OTypeKw, ITypeKw, BoolLiteral, DoubleEq, NotEq, LessEq, GreaterEq, AndAnd, OrOr, PlusPlus, MinusMinus, PlusEq, MinusEq, StarEq, SlashEq, PercentEq, LeftShift, RightShift, Arrow, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Colon, Semicolon, Dot, Comma, Question, Bang, At, Hash, Dollar, Percent, Caret, Ampersand, Star, Plus, Minus, Eq, LessThan, GreaterThan, Slash, Backslash, Pipe, Tilde,
}
Vampire token types.

Variants



Eof

End of file.



Whitespace

Whitespace.



LineComment

Line comment.



BlockComment

Block comment.



StringLiteral

String literal.



IntegerLiteral

Integer literal.



RealLiteral

Real literal.



Identifier

Identifier.



FofKw

The fof keyword (first-order formula).



CnfKw

The cnf keyword (conjunctive normal form).



TffKw

The tff keyword (typed first-order formula).



ThfKw

The thf keyword (typed higher-order formula).



TpiKw

The tpi keyword (typed predicate inference).



IncludeKw

The include keyword.



AxiomKw

The axiom keyword.



HypothesisKw

The hypothesis keyword.



DefinitionKw

The definition keyword.



AssumptionKw

The assumption keyword.



LemmaKw

The lemma keyword.



TheoremKw

The theorem keyword.



ConjectureKw

The conjecture keyword.



NegatedConjectureKw

The negated_conjecture keyword.



PlainKw

The plain keyword.



TypeKw

The type keyword.



FiDomainKw

The fi_domain keyword.



FiFunctorsKw

The fi_functors keyword.



FiPredicatesKw

The fi_predicates keyword.



UnknownKw

The unknown keyword.



ForallKw

The ! (forall) quantifier keyword.



ExistsKw

The ? (exists) quantifier keyword.



AndKw

The & (and) logical operator keyword.



OrKw

The | (or) logical operator keyword.



NotKw

The ~ (not) logical operator keyword.



ImpliesKw

The => (implies) logical operator keyword.



IffKw

The <=> (if and only if) logical operator keyword.



XorKw

The <~> (xor) logical operator keyword.



NorKw

The ~| (nor) logical operator keyword.



NandKw

The ~& (nand) logical operator keyword.



BoolKw

The $bool type keyword.



IndividualKw

The $i (individual) type keyword.



IntKw

The $int type keyword.



RealKw

The $real type keyword.



RatKw

The $rat type keyword.



TTypeKw

The $tType type keyword.



OTypeKw

The $o type keyword.



ITypeKw

The $iType type keyword.



BoolLiteral

Boolean literal ($true or $false).



DoubleEq

The == equality operator.



NotEq

The != inequality operator.



LessEq

The <= less-than-or-equal operator.



GreaterEq

The >= greater-than-or-equal operator.



AndAnd

The && logical and operator.



OrOr

The || logical or operator.



PlusPlus

The ++ increment operator.



MinusMinus

The -- decrement operator.



PlusEq

The += addition assignment operator.



MinusEq

The -= subtraction assignment operator.



StarEq

The *= multiplication assignment operator.



SlashEq

The /= division assignment operator.



PercentEq

The %= modulo assignment operator.



LeftShift

The << left shift operator.



RightShift

The >> right shift operator.



Arrow

The -> arrow operator.



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



Colon

Colon :.



Semicolon

Semicolon ;.



Dot

Dot ..



Comma

Comma ,.



Question

Question mark ?.



Bang

Exclamation mark !.



At

At sign @.



Hash

Hash #.



Dollar

Dollar sign $.



Percent

Percent %.



Caret

Caret ^.



Ampersand

Ampersand &.



Star

Asterisk *.



Plus

Plus +.



Minus

Minus -.



Eq

Equals =.



LessThan

Less-than <.



GreaterThan

Greater-than >.



Slash

Slash /.



Backslash

Backslash \.



Pipe

Pipe |.



Tilde

Tilde ~.